#
# spec file for package ninja-ide
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ninja-ide
Version:        2.4
Release:        bp156.3.2
Url:            http://www.ninja-ide.org
Summary:        Ninja IDE for Python development
License:        GPL-3.0
Group:          Development/Languages/Python
Source0:        https://github.com/ninja-ide/ninja-ide/archive/v%{version}.tar.gz
Source1:        %{name}.1.gz
Source99:       %{name}.rpmlintrc
Patch0:         python3-fixes.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  python3-devel
BuildRequires:  python3-pyinotify
BuildRequires:  python3-qt5-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-setuptools
BuildRequires:  unzip
BuildRequires:  update-desktop-files
BuildRequires:  zlib-devel
Requires:       python3-pyinotify
Requires:       python3-qt5
Requires:       python3-setuptools
BuildArch:      noarch

%description
Features:
  - Every common functionality of a typical IDE supported:
        - Project Management.
        - Automatic Indentation.
        - Code Folding.
        - Brace matching.
  - The System for Syntax Highlighting in NINJA-IDE is really easy to extend,
    just write a json file with the keywords, etc.
  - Code Locator and Code Navigation supported.
  - Allow to execute Python programs and render HTML files just pressing Ctrl+F6.
  - Code Completion supported!
  - Follow Mode and Split supported.
  - And many more... Stay up to date for more features!

%prep
%setup -q #-n ninja-ide
%patch0 -p1

%build
python3 setup.py build

%install
desktop-file-install --dir %{buildroot}%{_datadir}/applications ./ninja-ide.desktop
install -d %{buildroot}%{_datadir}/pixmaps/
cp icon.png %{buildroot}%{_datadir}/pixmaps/ninja-ide.png

mkdir -p %{buildroot}%{_mandir}/man1
cp %{SOURCE1} %{buildroot}%{_mandir}/man1/%{name}.1.gz

python3 setup.py install -O1 --skip-build --prefix=%{_prefix} --root=%{buildroot}
mkdir -p %{buildroot}%{python3_sitelib}
mv %{buildroot}/usr/share/NINJA-IDE/*  %{buildroot}%{python3_sitelib}
rmdir %{buildroot}/usr/share/NINJA-IDE

%suse_update_desktop_file -i ninja-ide Development IDE
%fdupes %{buildroot}%{python3_sitelib}
#find %%{buildroot} -name 'pep8mod.py' | xargs chmod 0755

%files
%defattr(-,root,root)
%{_bindir}/%{name}
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/*.png
%{python3_sitelib}/NINJA_IDE-%{version}-py*.egg-info
%{python3_sitelib}/ninja_ide
%{python3_sitelib}/ninja_tests
%{_mandir}/man1/%{name}.1.*

%changelog
* Wed Dec  9 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to ninja-ide 2.4
  * Ported to python3 and Qt5
- Add patch for a couple of missing bits that weren't ported from
  python2 to python3:
  * python3-fixes.patch
* Tue Dec  8 2015 jorge.izaac@gmail.com
- Explicitly add python-setuptools as installation requirement.
  * Fix for bug 958149: https://bugzilla.opensuse.org/show_bug.cgi?id=958149
* Mon Jul 13 2015 toddrme2178@gmail.com
- Install to prefix explicitly
  * Fixes building on SLES 11
* Thu Nov 20 2014 toddrme2178@gmail.com
- Include .rpmlinc file in sources.
- Provide url for source file verification.
- Switch to .desktop file included in the package.
* Thu Nov 20 2014 toddrme2178@gmail.com
- Require python-setuptools since the main package depends on it.
- Spec file cleanups
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Aug 20 2013 samuelw2011@tpg.com.au
- Updated source to stable version 2.3
  from the git repository
  * Last stable version before
    next major update - mostly bug fixes
* Thu Aug 15 2013 toddrme2178@gmail.com
- Fix depenency on setuptools, it conflicts with distribute below
  Factory
* Sun May 19 2013 samuelw2011@tpg.com.au
- updated to latest stable version 2.2. As stated in the release announcement <https://groups.google.com/forum/?fromgroups#!topic/ninja-ide/As4QCTXslfM>: "This new version includes several performance improves and bug fixes (specially a performance improve in the Python Syntax Highlighter, and soon it will be extended for the other languages supported in ninja)."
- changed setup line and name of source zip in spec file to suit new version
* Thu Nov 15 2012 jorge.izaac@gmail.com
- changed name of setup folder to match unzipped upstream file
- BuildRequire dependency for python-pyinotify
* Thu Nov 15 2012 jorge.izaac@gmail.com
-added upstream zip file
* Wed Nov 14 2012 jorge.izaac@gmail.com
- fix for build on SLE_11_SP2
* Fri Nov  9 2012 jorge.izaac@gmail.com
- added python build prefix for opensuse 12.2 and below
* Sat Nov  3 2012 jorge.izaac@gmail.com
- fixed pep8mod.py permissions and duplicated listing, fix taken from fedora spec file
* Sat Nov  3 2012 jorge.izaac@gmail.com
- missing setup statement added, new description and summary
* Sat Nov  3 2012 jorge.izaac@gmail.com
- Added stable 2.1.1 sources from ninja-ide git repository
- Spec file clean up, removed duplicated setup statement
